OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "No contacts in here" : "Nejsou zde žádné kontakty",
    "Name" : "Název",
    "Organization" : "Organizace",
    "Title" : "Název",
    "Add field ..." : "Přidat pole...",
    "Add contact" : "Přidat kontakt",
    "No search result for {query}" : "Žádný nález pro {query}",
    "All contacts" : "Všechny kontakty",
    "Not grouped" : "Neseskupené",
    "Post Office Box" : "Poštovní schránka",
    "Postal Code" : "Poštovní směrovací číslo",
    "City" : "Město",
    "State or province" : "Stát nebo provincie",
    "Country" : "Země",
    "Address" : "Adresa",
    "(new group)" : "(nová skupina)",
    "{addressbook} shared by {owner}" : "{addressbook} sdílí {owner}",
    "Nickname" : "Přezdívka",
    "Notes" : "Poznámky",
    "Website" : "Stránka",
    "Federated Cloud ID" : "Sdružené cloud ID",
    "Home" : "Domů",
    "Work" : "Práce",
    "Other" : "Jiný",
    "Groups" : "Skupiny",
    "Birthday" : "Narozeniny",
    "Email" : "Email",
    "Instant messaging" : "Komunikátor",
    "Phone" : "Telefon",
    "Mobile" : "Mobil",
    "Fax" : "Fax",
    "Fax home" : "Fax domů",
    "Fax work" : "Fax do práce",
    "Pager" : "Pager",
    "Voice" : "Hlas",
    "Settings" : "Nastavení",
    "Import" : "Importovat"
},
"nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
